--
-- Woirld Map Data of the Dungeon Locations addon
--
-- Author: staratnight
-- Date: 31.03.2018
-- Copyright 2018 - Torsten Mingers
--
-- Licensed under the terms of the GNU General Public License (Version 3).
-- You should have received a copy of the GNU General Public License
-- along with Dungeon Locations. If not, see <http://www.gnu.org/licenses/gpl-3.0.txt>.
--
-- See https://wow.curseforge.com/projects/dungeon-locations/issues to provide bugs or improvements.

local DungeonLocationsWorldMapData, DLoc = ...
local L = DLoc_Locals

local Kalimdor = 13;
local EasternKingdoms = 14;
local Outland = 466;
local Shattrath = 481;
local TerrokarForest = 478;
local Northrend = 485;
local Maelstrom = 751;
local Pandaria = 862;
local Draenor = 962;
local BrokenIsles = 1007;
local Argus = 1184;

local worldMapIds = { Kalimdor, EasternKingdoms, Outland, Shattrath, TerrokarForest, Northrend, Maelstrom, Pandaria, Draenor, BrokenIsles, Argus }

local worldMapLocations = {}

function SetupWorldMapData()
    local dungeons = DLoc:getDungeons()
    local areas = DLoc:getAreas()

    addWorldMapLocation(EasternKingdoms, 56, 5.5, { dungeons.MagistersTerrace, 
                                                        dungeons.SunwellPlateau })
    addWorldMapLocation(EasternKingdoms, 56, 25, { dungeons.ZulAman })
    addWorldMapLocation(EasternKingdoms, 53, 32, { dungeons.Stratholme })
    addWorldMapLocation(EasternKingdoms, 49, 34, { dungeons.Scholomance })
    addWorldMapLocation(EasternKingdoms, 45, 32, { dungeons.ScarletMonastery, dungeons.ScarletHalls })
    addWorldMapLocation(EasternKingdoms, 41, 41, { dungeons.ShadowfangKeep })
    addWorldMapLocation(EasternKingdoms, 35, 52, { dungeons.BaradinHold })
    addWorldMapLocation(EasternKingdoms, 55, 56, { dungeons.GrimBatol, dungeons.TheBastionOfTwilight })
    addWorldMapLocation(EasternKingdoms, 54, 67, { dungeons.Uldaman })
    addWorldMapLocation(EasternKingdoms, 42, 60, { dungeons.Gnomeregan })
    addWorldMapLocation(EasternKingdoms, 32, 64, { dungeons.ThroneOfTheTides })
    addWorldMapLocation(EasternKingdoms, 50, 72, { dungeons.BlackrockDepths, dungeons.UpperBlackrockSpire, dungeons.LowerBlackrockSpire, dungeons.BlackrockCaverns, 
											 	  dungeons.MoltenCore, dungeons.BlackwingLair, dungeons.BlackwingDescent })
    addWorldMapLocation(EasternKingdoms, 41, 70, { dungeons.TheStockade })
    addWorldMapLocation(EasternKingdoms, 41, 82, { dungeons.TheDeadmines }) 
    addWorldMapLocation(EasternKingdoms, 52, 79, { dungeons.SunkenTempel }) 
    addWorldMapLocation(EasternKingdoms, 50, 80, { dungeons.ReturnToKarazhan,
                                                        dungeons.Karazhan })
    addWorldMapLocation(EasternKingdoms, 48, 85, { dungeons.ZulGurub })

    addWorldMapLocation(Kalimdor, 54, 37, { dungeons.Firelands })
    addWorldMapLocation(Kalimdor, 44, 34, { dungeons.BlackfathomDeeps })
    addWorldMapLocation(Kalimdor, 60, 44, { dungeons.RagefireChasm })
    addWorldMapLocation(Kalimdor, 52, 52, { dungeons.WailingCaverns })
    addWorldMapLocation(Kalimdor, 38, 56, { dungeons.Maraudon })
    addWorldMapLocation(Kalimdor, 53, 69, { dungeons.RazorfenKraul })
    addWorldMapLocation(Kalimdor, 54, 73, { dungeons.RazorfenDowns })
    addWorldMapLocation(Kalimdor, 55, 69, { dungeons.OnyxiasLair })
    addWorldMapLocation(Kalimdor, 41, 67, { dungeons.DireMaulWest, dungeons.DireMaulEast, dungeons.DireMaulNorth })
    addWorldMapLocation(Kalimdor, 42, 85, { dungeons.RuinsOfAhnQiraj, dungeons.TempleOfAhnQiraj })
    addWorldMapLocation(Kalimdor, 56, 84, { dungeons.ZulFarrak, dungeons.EscapeFromDurnholde, dungeons.TheBlackMorass, dungeons.TheCullingOfStratholme, 
                                                dungeons.WellOfEternity, dungeons.HourOfTwilight, dungeons.EndTime,
                                            dungeons.TheBattleForMountHyjal, dungeons.Dragonsoul })
    addWorldMapLocation(Kalimdor, 49, 96, { dungeons.TheVortexPinnacle, dungeons.LostCityOfTheTolvir, dungeons.HallsOfOrigination,
                                                dungeons.ThroneOfTheFourWinds })

    addWorldMapLocation(Maelstrom, 51, 28, { dungeons.TheStonecore })

    addWorldMapLocation(Outland, 64, 16, { dungeons.TheArcatraz, dungeons.TheBotanica, dungeons.TheMechanar,
                                                dungeons.TheEye })
    addWorldMapLocation(Outland, 42, 24, { dungeons.GruulsLair })
    addWorldMapLocation(Outland, 35, 45, { dungeons.TheSlavePens, dungeons.TheUnderbog, dungeons.TheSteamvault,
                                            dungeons.SerpentshrineCavern })
    addWorldMapLocation(Outland, 55, 53, { dungeons.HellfireRamparts, dungeons.TheBloodFurnace, dungeons.TheShatteredHalls,
                                            dungeons.MagtheridonsLair })
    addWorldMapLocation(Outland, 46, 75, { dungeons.AuchenaiCrypts, dungeons.SethekkHalls, dungeons.ManaTombs, dungeons.ShadowLabyrinth, dungeons.MagistersTerrace, 
                                            dungeons.SunwellPlateau })
    addWorldMapLocation(Outland, 72, 81, { dungeons.TheBlackTemple })

    addWorldMapLocation(Shattrath, 49, 42, { dungeons.MagistersTerrace, 
                                                dungeons.SunwellPlateau })
    addWorldMapLocation(TerrokarForest, 28, 23, { dungeons.MagistersTerrace, 
                                                    dungeons.SunwellPlateau })

    addWorldMapLocation(Northrend, 58, 16, { dungeons.HallsOfLightning, dungeons.HallsOfStone, 
                                                dungeons.Ulduar })
    addWorldMapLocation(Northrend, 42, 30, { dungeons.TrialOfTheChampion, dungeons.TheForgeOfSouls, dungeons.PitOfSaron , dungeons.TheHallsOfReflection,
                                                dungeons.TrialOfTheCrusader, dungeons.IcecrownCitadel })
    addWorldMapLocation(Northrend, 73, 38, { dungeons.Gundrak })
    addWorldMapLocation(Northrend, 48, 40, { dungeons.TheVioletHold })
    addWorldMapLocation(Northrend, 36, 44, { dungeons.VaultOfArchavon })
    addWorldMapLocation(Northrend, 65, 55, { dungeons.DrakTharonKeep })
    addWorldMapLocation(Northrend, 50, 51, { dungeons.AzjolNerub, dungeons.AhnKahet, 
                                                dungeons.TheRubySanctum, dungeons.TheObsidianSanctum, dungeons.Naxxramas })
    addWorldMapLocation(Northrend, 12, 57, { dungeons.TheNexus, dungeons.TheOculus, 
                                                dungeons.TheEyeOfEternity })
    addWorldMapLocation(Northrend, 80, 76, { dungeons.UtgardeKeep, dungeons.UtgardePinnacle })              
          
    addWorldMapLocation(Pandaria, 24, 8, { dungeons.ThroneOfThunder })
    addWorldMapLocation(Pandaria, 41, 29, { dungeons.ShadoPanMonastery,
                                                dungeons.MogushanVaults })
    addWorldMapLocation(Pandaria, 22, 49, { dungeons.SiegeOfNiuzaoTemple })
    addWorldMapLocation(Pandaria, 55, 54, { dungeons.MogushanPalace, dungeons.GateOfTheSettingSun,
                                                dungeons.SiegeOfOrgrimmar })
    addWorldMapLocation(Pandaria, 70, 49, { dungeons.TempleOfTheJadeSerpent })
    addWorldMapLocation(Pandaria, 57, 52, { dungeons.TerraceOfEndlessSpring })
    addWorldMapLocation(Pandaria, 47, 71, { dungeons.StormstoutBrewery })
    addWorldMapLocation(Pandaria, 32, 64, { dungeons.HeartOfFear })

    addWorldMapLocation(Draenor, 50, 26, { dungeons.IronDocks, dungeons.GrimrailDepot, dungeons.TheEverbloom,
                                                dungeons.BlackrockFoundry })
    addWorldMapLocation(Draenor, 34, 28, { dungeons.BloodmaulSlagMines })
    addWorldMapLocation(Draenor, 58, 47, { dungeons.HellfireCitadel })
    addWorldMapLocation(Draenor, 20, 50, { dungeons.Highmaul })
    addWorldMapLocation(Draenor, 39, 62, { dungeons.Auchindoun })
    addWorldMapLocation(Draenor, 54, 67, { dungeons.ShadowmoonBurialGrounds })
    addWorldMapLocation(Draenor, 43, 74, { dungeons.Skyreach  })

    addWorldMapLocation(BrokenIsles, 47, 27, { dungeons.NeltharionsLair })
    addWorldMapLocation(BrokenIsles, 60, 32, { dungeons.HallsOfValor, dungeons.MawOfSouls,
                                                    dungeons.TrialOfValor })
    addWorldMapLocation(BrokenIsles, 33, 33, { dungeons.BlackRookHold, dungeons.DarkheartThicket,
                                                    dungeons.TheEmeraldNightmare })
    addWorldMapLocation(BrokenIsles, 37, 63, { dungeons.EyeOfAzshara, dungeons.VaultOfTheWardens})
    addWorldMapLocation(BrokenIsles, 49, 50, { dungeons.TheArcway, dungeons.CourtOfStars,
                                                    dungeons.TheNighthold })
    addWorldMapLocation(BrokenIsles, 46, 67, { dungeons.VioletHold })
    addWorldMapLocation(BrokenIsles, 87, 25, { dungeons.TheSeatOfTheTriumvirate,
                                                    dungeons.AntorusTheBurningThrone   })
    addWorldMapLocation(BrokenIsles, 57, 62, { dungeons.CathedralOfEternalNight,
                                                    dungeons.TheTombOfSageras   })                                                    

    addWorldMapLocation(Argus, 52, 29, { dungeons.TheSeatOfTheTriumvirate })                                                    
    addWorldMapLocation(Argus, 35, 57, { dungeons.AntorusTheBurningThrone })                                                    
     
end    

function addWorldMapLocation(id, x , y , dungeons)
    worldMapLocations[id][#worldMapLocations[id] + 1] = DLoc:CreateWorldMapLocation(x, y, dungeons);
end

function DLoc:getWorldMapDungeonLocations(worldMapId)
    return worldMapLocations[worldMapId]
end

function initializeWorldLocationMatrix()
    for k,v in ipairs(worldMapIds) do
        initializeWorldLocationMatrixWithId(v)
    end
end

function initializeWorldLocationMatrixWithId(id)
    worldMapLocations[id] = {}
end

function DLoc:isWorldMapId(id)
    if(worldMapLocations[id] ~= nil) then
        return true
    else
        return false
    end
end

function DLoc:CreateWorldMapLocations()
    initializeWorldLocationMatrix()
    SetupWorldMapData()    
 end